AudioStreamState

Enum AudioStreamState 

pub enum AudioStreamState {
    Ok,
    Err,
    Silence,
    Other(String),
}
Represents the state of an audio stream after processing. This indicates whether the stream processed normally or encountered issues.

Variants



Ok

Stream processing was successful.



Err

An internal error occurred; input buffer is filled with zeros.



Silence

The stream is silent; input buffer is filled with zeros.



Other(String)

Other error condition with a descriptive message; input buffer is filled with zeros.