pub struct AudioBufferInterleaved<T: FloatType> { /* private fields */ }Trait Implementations
Sourceimpl<T: FloatType> AudioBufferInterleavedImpl<T> for AudioBufferInterleaved<T>
impl<T: FloatType> AudioBufferInterleavedImpl<T> for AudioBufferInterleaved<T>
Sourcefn new(len: usize, layout: AudioChannelLayout) -> AudioBufferInterleaved<T>
fn new(len: usize, layout: AudioChannelLayout) -> AudioBufferInterleaved<T>
Creates a new interleaved audio buffer with the specified length (per channel) and channel layout.
The total buffer length will be
length * layout as usize.Sourcefn get_channel_layout(&self) -> AudioChannelLayout
fn get_channel_layout(&self) -> AudioChannelLayout
Returns the current channel layout of the buffer.
Sourcefn set_channel_layout(&mut self, layout: AudioChannelLayout)
fn set_channel_layout(&mut self, layout: AudioChannelLayout)
Sets a new channel layout, potentially reallocating the buffer if the layout changes.
Sourcefn get_buffer(&self) -> &[T]
fn get_buffer(&self) -> &[T]
Returns an immutable reference to the entire interleaved buffer.
Sourcefn get_buffer_mut(&mut self) -> &mut [T]
fn get_buffer_mut(&mut self) -> &mut [T]
Returns a mutable reference to the entire interleaved buffer.
Sourcefn len_planar(&self) -> usize
fn len_planar(&self) -> usize
Returns the length per channel (planar length).
Sourcefn len_interleaved(&self) -> usize
fn len_interleaved(&self) -> usize
Returns the total interleaved length (channels * planar length).
Sourcefn resize(&mut self, new_len: usize)
fn resize(&mut self, new_len: usize)
Resizes the buffer to a new planar length, adjusting the total size accordingly.
Sourcefn copy_to_planar(&self, output: &mut AudioBuffer<T>)
fn copy_to_planar(&self, output: &mut AudioBuffer<T>)
Copies the interleaved data into a planar AudioBuffer (separate buffers per channel).
Sourceimpl<T: FloatType> AudioBufferMathImpl<T> for AudioBufferInterleaved<T>
impl<T: FloatType> AudioBufferMathImpl<T> for AudioBufferInterleaved<T>
Sourceimpl<T: Clone + FloatType> Clone for AudioBufferInterleaved<T>
impl<T: Clone + FloatType> Clone for AudioBufferInterleaved<T>
Sourcefn clone(&self) -> AudioBufferInterleaved<T>
fn clone(&self) -> AudioBufferInterleaved<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<T> Freeze for AudioBufferInterleaved<T>
impl<T> RefUnwindSafe for AudioBufferInterleaved<T>where
T: RefUnwindSafe,
impl<T> Send for AudioBufferInterleaved<T>where
T: Send,
impl<T> Sync for AudioBufferInterleaved<T>where
T: Sync,
impl<T> Unpin for AudioBufferInterleaved<T>where
T: Unpin,
impl<T> UnwindSafe for AudioBufferInterleaved<T>where
T: UnwindSafe,