#[repr(usize)]pub enum AudioChannelLayout {
Mono = 1,
Stereo = 2,
Surround30 = 3,
Surround40 = 4,
Surround51 = 6,
Surround71 = 8,
}Expand description
Represents common audio channel layouts, where the enum variant’s repr(usize) corresponds to the number of channels in that layout.
Variants
Mono = 1
Single channel audio (monaural).
Stereo = 2
Two-channel audio (left and right).
Surround30 = 3
Three-channel surround sound (left, right, center).
Surround40 = 4
Four-channel surround sound (left, right, center, rear).
Surround51 = 6
Six-channel surround sound (5.1: left, right, center, LFE, left surround, right surround).
Surround71 = 8
Eight-channel surround sound (7.1: adds rear left and rear right).