pub trait AudioStreamFeederTrait<T: FloatType + Float> {
// Required method
fn process(
&mut self,
context: &AudioStreamContext,
input: &mut AudioBuffer<T>,
) -> AudioStreamState;
}Expand description
Trait for feeders that provide audio data to streams. Implementors process input buffers based on the provided context.
Required Methods
Sourcefn process(
&mut self,
context: &AudioStreamContext,
input: &mut AudioBuffer<T>,
) -> AudioStreamState
fn process( &mut self, context: &AudioStreamContext, input: &mut AudioBuffer<T>, ) -> AudioStreamState
Processes the input audio buffer using the given context. Returns the state of the stream after processing.