pub type ParamPropDesk<'a, const N: usize> = [(&'a str, EffectParamType); N];Expand description
Alias for parameter property descriptions.
This is an array of tuples, each containing a parameter name and its type.
The const generic N specifies the number of parameters.